module FFmpegProgress
  # Contains various examples of +ffmpeg+ options.
  module Presets
    # The default options. Convert the video to x264 and audio to AAC.
    DEFAULT_OPTIONS = '-y -threads 0 -strict -2 -c:a aac -b:a 96k ' \
      '-c:v libx264 -preset fast -tune fastdecode -crf 22 '

    # Read the default subtitles embedded in an input MKV file and hardcode
    # them into the video. Any embedded fonts must be extracted and installed
    # first to preserve them in the output, for example:
    #   mkvextract attachments input.mkv {1..10}
    #   cp *.ttf *.ttc *.otf ~/.fonts
    BURN_MKV_SUBS = '-y -threads 0 -strict -2 -sn -c:a copy ' \
      '-c:v libx264 -preset fast -tune fastdecode -crf 22 ' \
      '-vf "subtitles=_INPUT_"'

    # Like {BURN_MKV_SUBS}, but also downscale the video to 800px width.
    BURN_800 = '-y -threads 0 -strict -2 -sn -c:a aac -b:a 96k ' \
      '-c:v libx264 -preset fast -tune fastdecode -crf 22 ' \
      '-vf "[in]scale=800:-2[tmp];[tmp]subtitles=_INPUT_[out]"'

    # Scale to 800px width.
    WIDTH_800 = '-y -threads 0 -strict -2 -sn -c:a aac -b:a 96k ' \
      '-c:v libx264 -preset fast -tune fastdecode -crf 22 ' \
      '-vf scale=800:-2'
  end
end
